import React, {useContext} from 'react';
import {Image, StyleSheet, Text, View} from 'react-native';
import {AppContext} from '..';

export default function AvatarContainer({size, user}) {
  const {avatarWidth} = useContext(AppContext);

  return (
    <View style={[styles.main, {width: avatarWidth}]}>
      <Image
        style={{
          width: size,
          height: size,
          borderRadius: size,
        }}
        source={
          user?.avatar
            ? {uri: user.avatar}
            : require('../icons/icon-square.png')
        }
        resizeMode="cover"
      />
      <Text style={styles.name}>{user.name}</Text>
      <View style={styles.verticalLine} />
    </View>
  );
}

const styles = StyleSheet.create({
  main: {
    flexDirection: 'row',
    minWidth: 140,
    paddingHorizontal: 2,
    alignItems: 'center',
    marginHorizontal: 5,
  },
  name: {
    fontWeight: 'bold',
    fontSize: 16,
    justifyContent: 'center',
    marginLeft: 5,
    flex: 1,
    flexWrap: 'wrap',
  },
  verticalLine: {
    width: 1,
    height: 3000,
    position: 'absolute',
    backgroundColor: '#BABABA',
    right: 0,
  },
});
