import moment from 'moment';
import React, {useEffect, useState} from 'react';
import {FlatList, StyleSheet, Text, View} from 'react-native';
import Colors from '../../constants/colors';
import {buildCalender} from '../../services/build';
import Next from '../Next';
import Date from './Date';

const Calender = ({value, onChange}) => {
  const [calender, setCalender] = useState([]);
  const day = Number(value.format('D'));

  useEffect(() => {
    setCalender(buildCalender(value));
  }, [value]);

  const currMonthAndYear = () => {
    return value.format('MMMM YYYY');
  };

  const currentDay = () => {
    return value.format('dddd');
  };

  const decMonth = () => {
    return value.clone().subtract(1, 'month');
  };

  const incMonth = () => {
    return value.clone().add(1, 'month');
  };

  const getItemLayout = (data, index) => {
    return {
      length: 60,
      offset: 60 * index,
      index,
    };
  };

  const renderItem = ({item, index}) => {
    return (
      <Date
        date={item}
        index={index}
        key={index}
        isActive={value.isSame(item, 'day') ? true : false}
        onPress={() => onChange(item)}
      />
    );
  };
  return (
    <View>
      <View style={styles.headerContainer}>
        {value.isSame(moment(), 'day') ? (
          <Text style={styles.status}>Today</Text>
        ) : null}
        <Next
          onChange={() => onChange(decMonth())}
          icon={'<'}
          iconStyle={styles.leftIcon}
        />
        <Text style={styles.headerText}>{currMonthAndYear()}</Text>
        <Next
          onChange={() => onChange(incMonth())}
          icon={'>'}
          iconStyle={styles.rightIcon}
        />
        <Text style={styles.week}>{currentDay()}</Text>
      </View>
      <View style={styles.container}>
        <FlatList
          showsHorizontalScrollIndicator={false}
          horizontal
          data={calender}
          renderItem={renderItem}
          keyExtractor={item => item}
          getItemLayout={getItemLayout}
          initialScrollIndex={day - 1}
        />
      </View>
    </View>
  );
};

export default Calender;

const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
    marginBottom: 20,
  },
  image: {
    width: 20,
    height: 20,
  },
  headerText: {
    color: Colors.dark_gray,
    fontSize: 20,
  },
  headerContainer: {
    flexDirection: 'row',
    justifyContent: 'center',
    marginBottom: 20,
  },
  status: {
    position: 'absolute',
    left: 0,
    color: Colors.dark_gray,
    fontSize: 18,
  },
  week: {
    position: 'absolute',
    right: 0,
    color: Colors.dark_gray,
    fontSize: 18,
  },
  leftIcon: {
    fontSize: 20,
    paddingRight: 5,
  },
  rightIcon: {
    fontSize: 20,
    paddingLeft: 5,
  },
});
