import moment from 'moment';
import React, {useContext} from 'react';
import {Image, ScrollView, StyleSheet, Text, View} from 'react-native';
import {AppContext} from '../index';
import {hrsToStart} from '../services/hrsToPx';

const EventView = ({topTime, appt, hour_size}) => {
  const margin = hrsToStart(appt.startTime, topTime) * hour_size;
  const start = appt?.startTime ? moment(appt.startTime).format('hh:mm') : '';
  const end = appt?.endTime ? moment(appt.endTime).format('hh:mm') : '';
  const {resources, avatarWidth} = useContext(AppContext);
  const user = resources.find(resource => resource?.id === appt?.resourceId);
  return (
    <View
      style={[
        styles.eventContainer,
        {marginTop: margin, height: appt?.height, width: avatarWidth},
      ]}>
      <ScrollView nestedScrollEnabled={true} bounces={false}>
        <Text>
          {start} - {end}
        </Text>
        <Image
          style={styles.image}
          source={
            user?.avatar
              ? {uri: user.avatar}
              : require('../icons/icon-square.png')
          }
        />
        <Text>{user?.name ?? ''}</Text>
        <Text>{appt?.title ?? ''}</Text>
      </ScrollView>
    </View>
  );
};

const styles = StyleSheet.create({
  eventContainer: {
    backgroundColor: '#c2b1a3',
    borderRadius: 16,
    paddingHorizontal: 10,
    paddingVertical: 5,
    minWidth: 140,
    marginRight: 10,
  },
  image: {
    width: 40,
    height: 40,
    marginVertical: 3,
  },
});

export default EventView;
