import moment from 'moment';
import PropTypes from 'prop-types';
import React, {useEffect, useRef, useState} from 'react';
import {
  Dimensions,
  SafeAreaView,
  ScrollView,
  StyleSheet,
  View,
} from 'react-native';
import AvatarContainer from './components/AvatarContainer';
import Calender from './components/Calender';
import HorizontalLine from './components/HorizontalLine';
import NowLine from './components/NowLine';
import ScheduledData from './components/ScheduledData';
import Time from './components/Time';
import {hourSize} from './constants/hourSize';
import {processedData} from './services/processedData';

export const AppContext = React.createContext();

const Scheduler = ({events, resources}) => {
  const [value, setValue] = useState(moment());

  const data = !!events && processedData(events, hourSize);
  const getscreenwidth = width => Math.max(resources?.length * 150 + 60, width);

  const getavatarwidth = width => (width - 70) / resources?.length;

  const getminlinewidth = width => width;

  const geteventmarginwidth = width => {
    let marginWidth;
    if ((width - 50) / resources.length > 150) {
      marginWidth = (width - 50) / resources.length;
    } else {
      marginWidth = 150;
    }
    return marginWidth;
  };

  const [screenWidth, setscreenWidth] = useState(
    getscreenwidth(Dimensions.get('window').width),
  );
  const [avatarWidth, setavatarWidth] = useState(
    getavatarwidth(Dimensions.get('window').width),
  );
  const [minlineWidth, setminlineWidth] = useState(
    getminlinewidth(Dimensions.get('window').width),
  );
  const [eventmarginWidth, seteventmarginWidth] = useState(
    geteventmarginwidth(Dimensions.get('window').width),
  );

  useEffect(() => {
    scroll();
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  const scrollRef = useRef();

  useEffect(() => {
    const listner = Dimensions.addEventListener('change', adaptLayout);
    return () => listner.remove();
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, []);

  const adaptLayout = () => {
    setscreenWidth(getscreenwidth(Dimensions.get('window').width));
    setavatarWidth(getavatarwidth(Dimensions.get('window').width));
    setminlineWidth(getminlinewidth(Dimensions.get('window').width));
    seteventmarginWidth(getminlinewidth(Dimensions.get('window').width));
  };

  const _nowHeight = () => {
    var midnight = new Date();
    midnight.setHours(0, 0, 0, 0);
    var now = new Date();
    var hours = (now - midnight) / 3600000;
    return hours * hourSize - 100;
  };

  const scroll = () => {
    setTimeout(() => {
      scrollRef.current.scrollTo({
        x: 0,
        y: _nowHeight(),
        animated: true,
      });
    }, 300);
  };

  return (
    <AppContext.Provider
      value={{
        resources,
        avatarWidth,
        minlineWidth,
        eventmarginWidth,
      }}>
      <SafeAreaView style={styles.container}>
        <Calender value={value} onChange={setValue} />

        <ScrollView horizontal bounces={false}>
          <ScrollView ref={scrollRef} stickyHeaderIndices={[0]} bounces={false}>
            <View style={styles.background}>
              <View style={styles.dir}>
                {resources.map((item, index) => (
                  <AvatarContainer size={55} user={item} key={index} />
                ))}
              </View>
            </View>
            <View>
              <View style={[styles.body, {width: screenWidth}]}>
                <View style={styles.hour_col}>
                  <Time hour_size={hourSize} />
                </View>
                <View style={styles.schedule_col}>
                  <NowLine selectedDate={value} />
                  <HorizontalLine />
                  {!!data && <ScheduledData dataArray={data} date={value} />}
                </View>
              </View>
            </View>
          </ScrollView>
        </ScrollView>
      </SafeAreaView>
    </AppContext.Provider>
  );
};

const styles = StyleSheet.create({
  body: {
    flex: 1,
    flexDirection: 'row',
  },
  hour_col: {
    width: 60,
    flexDirection: 'column',
  },
  schedule_col: {
    flex: 1,
  },
  container: {
    paddingBottom: 20,
    backgroundColor: 'white',
  },
  avatarContainer: {
    marginBottom: 20,
  },
  image: {
    width: 40,
    height: 40,
  },
  dir: {
    flexDirection: 'row',
    marginLeft: 60,
  },
  background: {
    backgroundColor: 'white',
  },
});

Scheduler.propTypes = {
  events: PropTypes.array.isRequired,
  resources: PropTypes.array.isRequired,
};

Scheduler.defaultProps = {
  events: [],
  resources: [],
};

export default Scheduler;
